//********************************************************
//*** MFCtutorial.cpp - MFC Tutorial Part 
//*** by Emil Vassev
//********************************************************
#include <afxwin.h> //**** this is the MFC library

/**
 * This class defines the application's window.
 */
class MFCTutorialWindow: public CFrameWnd
{
public:
    MFCTutorialWindow()
    {
         Create(
             NULL, //**** use the default window properties for this window class
             _T("MFC Tutorial"), //**** _T is generic text data type
             WS_OVERLAPPEDWINDOW, //**** full-featured window
             CRect( 200, 100, 550, 500 ) ); //**** screen coordinates

		 x=y=20;
		 cx=cy=100;
    };

public:
    void OnLButtonDown(UINT nFlags, CPoint point);
    void OnRButtonDown(UINT nFlags, CPoint point);
    void OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags);
    DECLARE_MESSAGE_MAP();

private:
	int x,y,cx,cy;
};

//**** Message map macro
BEGIN_MESSAGE_MAP(MFCTutorialWindow, CFrameWnd)
      ON_WM_LBUTTONDOWN() //**** Macro to map the left button click to the handler
      ON_WM_RBUTTONDOWN() //**** Macro to map the right button click to the handler

	  ON_WM_KEYDOWN()

END_MESSAGE_MAP()

/**
 * Defines the handler of ON_WM_LBUTTONDOWN message. 
 */
void MFCTutorialWindow::OnLButtonDown(UINT nFlags, CPoint point) 
{
   CFrameWnd::OnLButtonDown(nFlags, point);
   MessageBox(_T("Left mouse button pressed"));
};

/**
 * Defines the handler of ON_WM_RBUTTONDOWN message. 
 */
void MFCTutorialWindow::OnRButtonDown(UINT nFlags, CPoint point) 
{
   CFrameWnd::OnRButtonDown(nFlags, point);
   MessageBox(_T("Right mouse button pressed"));
};

/**
 * Defines the handler of ON_WM_KEYDOWN message. 
 */
void MFCTutorialWindow::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags) 
{
   CFrameWnd::OnKeyDown(nChar, nRepCnt, nFlags);
   CClientDC dc(this);

   dc.Draw3dRect(x, y, cx, cy, RGB(255, 255, 255), RGB(255, 255, 255));
   
   if (nChar==VK_LEFT)
		x--;
   else if (nChar==VK_RIGHT)
		x++;

   // draw a rectangle with red top and left sides, and
   // green right and bottom sides.
   dc.Draw3dRect(x, y, cx, cy, RGB(255, 0, 0), RGB(0, 255, 0));

};

/**
 * This class defines the windows application.
 * It defines the InitInstance member function.
 */
class MFCTutorialApp: public CWinApp
{
   MFCTutorialWindow *wnd; //**** pointer to the window
public:
   /**
    * Override InitInstance to initialize a new instance of your application running under Windows.
    */
   BOOL InitInstance()
   {
        wnd = new MFCTutorialWindow(); //**** create window
        m_pMainWnd = wnd; //**** this data member stores a pointer to our thread's main window object
        m_pMainWnd->ShowWindow(SW_SHOWNORMAL);

        return true; //**** report success
   }
};

MFCTutorialApp theApp; //**** instantiate the application


